# Orange_Vision
FRC Orange Vision package

https://pypi.org/project/Orange_Vision/

### How to use

`sudo pip3 install Orange_Vision`
 
> sudo is for running scripts


*The scripts below are part of the pip package so you can just run them in terminal no need to git clone or anything just pip install*






### run server

`orange_detect_server`



### run with inference

`orange_detect_server --enable_ai`


### enable .local

`wifi_down.sh`

### disable .local

`wifi_up.sh`

### autoboot
`autoboot.sh`


### stop autoboot and kill server
`kill.sh`


